# Middleware DI API

::: wd.di.middleware_di.MiddlewareBuilder
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware_di.ApplicationBuilder
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware_di.create_application_builder
    handler: python
    options:
      show_root_heading: true
      show_source: false
